const emit = (vnode, event, data) => {
  if (vnode.componentInstance) {
    vnode.componentInstance.$emit(event, { detail: data })
  } else {
    vnode.elm.dispatchEvent(new CustomEvent(event, { detail: data }));
  }
}

const XxAttr = 'x-widget'

const eventPool = {

}

function registerDragStart(el,binding){
  const { value = {} }=binding
  el.setAttribute('draggable', 'true')
  eventPool.dragStart = event=>{
    event.stopPropagation()
    const type = XxAttr
    const d = JSON.stringify({
      text: value,
      type,
    })
    event.dataTransfer.setData(type, XxAttr)
    event.dataTransfer.setData('text/plain', d)
    event.dataTransfer.effectAllowed = 'move'
  }
  el.addEventListener('dragstart',eventPool.dragStart,false)
}

function unRegisterDragStart(el){
  el.removeAttribute('draggable')
  el.removeEventListener('dragstart',eventPool.dragStart)
}

function registerDrop(el,binding,vnode){
  eventPool.dragover = event=>{
    event.stopPropagation()
    const data = event.dataTransfer.types
    const idx = data.findIndex((item) => item === XxAttr)
    if (idx > -1) {
      event.preventDefault()
    }
  }
  eventPool.drop = event=>{
    event.stopPropagation()
    const data = event.dataTransfer.getData('text')
    const json = JSON.parse(data)
    emit(vnode,'droped', json)
  }
  el.addEventListener('dragover',eventPool.dragover,false)
  el.addEventListener('drop',eventPool.drop,false)
}
function unRegisterDrop(el){
  el.removeEventListener('drop',eventPool.drop)
  el.removeEventListener('dragover',eventPool.dragover)
}

export const XDrag = {
  bind(el, binding, vnode) {
    registerDragStart(el,binding,vnode)
  },
  unbind: function (el) {
    unRegisterDragStart(el)
  },
  update: function (el, binding, vnode) {
    unRegisterDragStart(el)
    registerDragStart(el,binding,vnode)
    return
  }
}

export const XDrop = {
  bind(el, binding, vnode) {
    registerDrop(el,binding,vnode)
  },
  unbind: function (el) {
    unRegisterDrop(el)
  },
  update: function (el, binding, vnode) {
    unRegisterDrop(el)
    registerDrop(el,binding,vnode)
    return
  }
}
